# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from .models import Country, AdministrativeArea


class AdministrativeAreaInline(admin.TabularInline):
    model = AdministrativeArea
    extra = 0


class CountryAdmin(admin.ModelAdmin):
    list_display = ('printable_name', 'iso2_code', 'iso3_code',)
    fieldsets = (
        (_("denomination"), {
            'fields': ('printable_name', 'name'),
        }),
        (_("codes"), {
            'fields': ('iso2_code', 'iso3_code', 'numcode',)
        }),
        (None, {
            'fields': ('continent', 'admin_area',),
        }),
    )
    search_fields = ('name', 'iso2_code', 'iso3_code',)
    inlines = (AdministrativeAreaInline,)


admin.site.register(Country, CountryAdmin)
